@@ -1199,15 +1199,6 @@ class Base_Page(Borg, unittest.TestCase):
         """After run this function, Base_page.current_console_log_errors should store the console log"""
         pass
 
-    def add_cookies(self):
-        if self.product == "QCare":
-            if self.test_env == "prod":
-                qcareCashierCookie = {'domain': 'qcare.qhms.com', 'expiry': 1664265608, 'httpOnly': False, 'name': 'Qcare.CashierNo.X000', 'path': '/', 'secure': True, 'value': 'qPAAAO2quqkDJXx0'}
-                self.driver.add_cookie(qcareCashierCookie)
-            else:
-                qcareCashierCookie = {'domain': 'uat-qcare.qhms.com', 'expiry': 1664355109, 'httpOnly': False, 'name': 'Qcare.CashierNo.X000', 'path': '/', 'secure': True, 'value': 'qPAAAIeg/lADJXx0'}
-                self.driver.add_cookie(qcareCashierCookie)
-
     def get_cookies(self):
         return self.driver.get_cookies()
 
